
import com.imsl.stat.*;
import com.imsl.math.*;

public class UserBasisRegressionEx2 {

    public static void main(String args[]) {
        class Basis implements RegressionBasis {

            public double basis(int index, double x) {
                // Notice zero-based indexing requires index be incremented
                return Math.pow(x, index + 1);
            }
        }

        UserBasisRegression ubr
                = new UserBasisRegression(new Basis(), 4, true);

        for (double x = 0; x < 10; x++) {
            double y = 10.0 + x + 3 * Math.pow(x, 3);
            ubr.update(x, y, 1.0);
        }

        // Print the regression coefficients
        double coef[] = ubr.getCoefficients();
        new PrintMatrix("The regression coefficients are:").print(coef);

        // Print the Anova Table
        ANOVA anovaTable = ubr.getANOVA();

        System.out.println("Degrees Of Freedom For Model:          "
                + anovaTable.getDegreesOfFreedomForModel());
        System.out.println("Degrees Of Freedom For Error:          "
                + anovaTable.getDegreesOfFreedomForError());
        System.out.println("Total (Corrected) Degrees Of Freedom:  "
                + anovaTable.getTotalDegreesOfFreedom());
        System.out.println("Sum Of Squares For Model:              "
                + anovaTable.getSumOfSquaresForModel());
        System.out.println("Sum Of Squares For Error:              "
                + anovaTable.getSumOfSquaresForError());
        System.out.println("Total (Corrected) Sum Of Squares:      "
                + anovaTable.getTotalSumOfSquares());
        System.out.println("Model Mean Square:                     "
                + anovaTable.getModelMeanSquare());
        System.out.println("Error Mean Square:                     "
                + anovaTable.getErrorMeanSquare());
        System.out.println("F statistic:                           "
                + anovaTable.getF());
        System.out.println("P value:                               "
                + anovaTable.getP());
        System.out.println("R Squared (in percent):                "
                + anovaTable.getRSquared());
        System.out.println("Adjusted R Squared (in percent):       "
                + anovaTable.getAdjustedRSquared());
        System.out.println("Model Error Standard deviation:        "
                + anovaTable.getModelErrorStdev());
        System.out.println("Mean Of Y:                             "
                + anovaTable.getMeanOfY());
        System.out.println("Coefficient Of Variation (in percent): "
                + anovaTable.getCoefficientOfVariation());
    }
}
